# Collaborative Literature Reviews (CoLRev)

<p align="center">
<img src="https://raw.githubusercontent.com/CoLRev-Ecosystem/colrev/main/docs/figures/logo_small.png" width="400">
</p>

<div align="center">

[![DOI](https://zenodo.org/badge/363073613.svg)](https://zenodo.org/badge/latestdoi/363073613)
[![GitHub release](https://img.shields.io/github/v/release/CoLRev-Ecosystem/colrev.svg)](https://github.com/CoLRev-Environment/colrev/releases/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/colrev)
[![License](https://img.shields.io/github/license/CoLRev-Ecosystem/colrev.svg)](https://github.com/CoLRev-Environment/colrev/releases/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Documentation Status](https://readthedocs.org/projects/colrev/badge/?version=latest)](https://colrev.readthedocs.io/en/latest/?badge=latest)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/CoLRev-Ecosystem/colrev/tests.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/CoLRev-Ecosystem/colrev/main.svg)](https://results.pre-commit.ci/latest/github/CoLRev-Ecosystem/colrev/main)
![Coverage](https://raw.githubusercontent.com/CoLRev-Ecosystem/colrev/main/tests/coverage.svg)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/bd4e44c6cda646e4b9e494c4c4d9487b)](https://app.codacy.com/gh/CoLRev-Environment/colrev/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
![GitHub last commit](https://img.shields.io/github/last-commit/CoLRev-Ecosystem/colrev)
[![Downloads](https://static.pepy.tech/badge/colrev/month)](https://pepy.tech/project/colrev)
[![OpenSSF Best Practices](https://bestpractices.coreinfrastructure.org/projects/7148/badge)](https://bestpractices.coreinfrastructure.org/projects/7148)
[![SWH](https://archive.softwareheritage.org/badge/origin/https://github.com/CoLRev-Environment/colrev/)](https://archive.softwareheritage.org/browse/origin/?origin_url=https://github.com/CoLRev-Environment/colrev/)<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-16-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->
<!-- ![PyPI](https://img.shields.io/pypi/v/colrev) -->
<!-- [![](https://img.shields.io/badge/-documentation-green)](https://colrev.readthedocs.io/) -->

</div>

## Summary

CoLRev is an open-source environment for collaborative literature reviews. It integrates with differerent synthesis tools, takes care of the data, and facilitates Git-based collaboration.

To accomplish these goals, CoLRev advances the design of review technology at the intersection of methods, design, cognition, and community building.
The following features stand out:

- An open and extensible environment based on shared data and process standards
- Builds on git and its transparent collaboration model for the entire literature review process
- Offers a self-explanatory, fault-tolerant, and configurable user workflow
- Operates a model for data quality, content curation, and reuse
- Enables typological and methodological pluralism throughout the process

See the [statements of development status](https://colrev.readthedocs.io/en/latest/foundations/dev_status.html) and [documentation](https://colrev.readthedocs.io/en/latest/) for more details. A brief overview presented at ESMARConf2023 is available on [YouTube](https://www.youtube.com/watch?v=yfGGraQC6vs).

## Contributing, changes, and releases

Contributions, code and features are always welcome

- See [contributing guidelines](CONTRIBUTING.md), [help page](https://colrev.readthedocs.io/en/latest/manual/help.html), and [github repository](https://github.com/CoLRev-Environment/colrev).
- Bug reports or feedback? Please use the [issue tracker](https://github.com/CoLRev-Environment/colrev/issues) and let us know.
- To get your work included, fork the repository, implement your changes, and create a [pull request](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/proposing-changes-to-your-work-with-pull-requests/about-pull-requests).

For further information, see [tests](tests/readme.md), [changes](CHANGELOG.md), and [releases](https://github.com/CoLRev-Environment/colrev/releases).

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/geritwagner"><img src="https://avatars.githubusercontent.com/u/3872815?v=4?s=100" width="100px;" alt="Gerit Wagner"/><br /><sub><b>Gerit Wagner</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=geritwagner" title="Code">💻</a> <a href="https://github.com/CoLRev-Environment/colrev/commits?author=geritwagner" title="Documentation">📖</a> <a href="#data-geritwagner" title="Data">🔣</a> <a href="#content-geritwagner" title="Content">🖋</a> <a href="#example-geritwagner" title="Examples">💡</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://julianprester.com"><img src="https://avatars.githubusercontent.com/u/4706870?v=4?s=100" width="100px;" alt="Julian Prester"/><br /><sub><b>Julian Prester</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=julianprester" title="Code">💻</a> <a href="https://github.com/CoLRev-Environment/colrev/commits?author=julianprester" title="Documentation">📖</a> <a href="#data-julianprester" title="Data">🔣</a> <a href="#content-julianprester" title="Content">🖋</a> <a href="https://github.com/CoLRev-Environment/colrev/issues?q=author%3Ajulianprester" title="Bug reports">🐛</a> <a href="#ideas-julianprester" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/tmahmood"><img src="https://avatars.githubusercontent.com/u/34904?v=4?s=100" width="100px;" alt="Tarin Mahmood"/><br /><sub><b>Tarin Mahmood</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=tmahmood" title="Code">💻</a> <a href="https://github.com/CoLRev-Environment/colrev/commits?author=tmahmood" title="Tests">⚠️</a> <a href="https://github.com/CoLRev-Environment/colrev/commits?author=tmahmood" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/dengdenglele"><img src="https://avatars.githubusercontent.com/u/28404427?v=4?s=100" width="100px;" alt="dengdenglele"/><br /><sub><b>dengdenglele</b></sub></a><br /><a href="#data-dengdenglele" title="Data">🔣</a> <a href="https://github.com/CoLRev-Environment/colrev/commits?author=dengdenglele" title="Documentation">📖</a> <a href="https://github.com/CoLRev-Environment/colrev/commits?author=dengdenglele" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/mhlbrsimon"><img src="https://avatars.githubusercontent.com/u/83401831?v=4?s=100" width="100px;" alt="mhlbrsimon"/><br /><sub><b>mhlbrsimon</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=mhlbrsimon" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ossendorfluca"><img src="https://avatars.githubusercontent.com/u/112037612?v=4?s=100" width="100px;" alt="ossendorfluca"/><br /><sub><b>ossendorfluca</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=ossendorfluca" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/katharinaernst"><img src="https://avatars.githubusercontent.com/u/131549085?v=4?s=100" width="100px;" alt="katharinaernst"/><br /><sub><b>katharinaernst</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=katharinaernst" title="Code">💻</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/einfachjessi"><img src="https://avatars.githubusercontent.com/u/131001755?v=4?s=100" width="100px;" alt="einfachjessi"/><br /><sub><b>einfachjessi</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=einfachjessi" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Janus678"><img src="https://avatars.githubusercontent.com/u/131582517?v=4?s=100" width="100px;" alt="Janus678"/><br /><sub><b>Janus678</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=Janus678" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/frxdericz"><img src="https://avatars.githubusercontent.com/u/131789939?v=4?s=100" width="100px;" alt="frxdericz"/><br /><sub><b>frxdericz</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=frxdericz" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/MalouSchmidt"><img src="https://avatars.githubusercontent.com/u/131263679?v=4?s=100" width="100px;" alt="MalouSchmidt"/><br /><sub><b>MalouSchmidt</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=MalouSchmidt" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/RheaDoesStuff"><img src="https://avatars.githubusercontent.com/u/74066245?v=4?s=100" width="100px;" alt="RheaDoesStuff"/><br /><sub><b>RheaDoesStuff</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=RheaDoesStuff" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Cohen2000"><img src="https://avatars.githubusercontent.com/u/113113352?v=4?s=100" width="100px;" alt="Cohen2000"/><br /><sub><b>Cohen2000</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=Cohen2000" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/RobertAhr"><img src="https://avatars.githubusercontent.com/u/131687952?v=4?s=100" width="100px;" alt="RobertAhr"/><br /><sub><b>RobertAhr</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=RobertAhr" title="Code">💻</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ThomasFleischmann"><img src="https://avatars.githubusercontent.com/u/131684139?v=4?s=100" width="100px;" alt="ThomasFleischmann"/><br /><sub><b>ThomasFleischmann</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=ThomasFleischmann" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/AntonFrisch"><img src="https://avatars.githubusercontent.com/u/131719653?v=4?s=100" width="100px;" alt="AntonFrisch"/><br /><sub><b>AntonFrisch</b></sub></a><br /><a href="https://github.com/CoLRev-Environment/colrev/commits?author=AntonFrisch" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## License

This project is distributed under the [MIT License](LICENSE) the documentation is distributed under the [CC-0](https://creativecommons.org/publicdomain/zero/1.0/) license.
If you contribute to the project, you agree to share your contribution following these licenses.

## Citing CoLRev

Please [cite](docs/_static/colrev_citation.bib) the project as follows:

Wagner, G. and Prester, J. (2023) CoLRev - An open-source environment for Collaborative Literature Reviews. Available at https://github.com/CoLRev-Environment/colrev.
